@@ -22,7 +22,7 @@ import matplotlib.pyplot as plt
 import time
 from numba import jit
 import numba
-from ._sirius_utils._constants import map_mueler_to_pol
+from sirius_data._constants import map_mueler_to_pol
 
 def calc_vis(uvw,vis_data_shape,point_source_flux,point_source_ra_dec,pointing_ra_dec,phase_center_ra_dec,antenna1,antenna2,freq_chan,beam_model_map,beam_models, parallactic_angle, pol, mueller_selection):
     """
@@ -100,7 +100,7 @@ def calc_vis_jit(vis_data,uvw,vis_data_shape,point_source_flux,point_source_ra_d
     
     #print(f_pt_time, f_pt_ant, do_pointing)
     
-    
+    #print('in calc vis')
     #print('pointing_ra_dec',pointing_ra_dec.dtype,point_source_ra_dec.dtype)
 
     for i_time in range(n_time):
@@ -123,9 +123,10 @@ def calc_vis_jit(vis_data,uvw,vis_data_shape,point_source_flux,point_source_ra_d
                 #print('ra_dec_out',ra_dec_out)
                 if not(np.array_equal(prev_ra_dec_in, ra_dec_in) and np.array_equal(prev_ra_dec_out, ra_dec_out)):
                     uvw_rotmat, lmn_rot = _calc_rotation_mats(ra_dec_in, ra_dec_out)
-                    #lm_sin = _sin_project(ra_dec_in,ra_dec_out)
-                    lm_sin = lmn_rot #use 37 in apply_primary_beam r = 2.0*np.arcsin(np.sqrt(np.sum(lmn**2))/2.0)
+                    lm_sin = _sin_project(ra_dec_in,ra_dec_out)
+                    #lm_sin = lmn_rot #use 37 in apply_primary_beam r = 2.0*np.arcsin(np.sqrt(np.sum(lmn**2))/2.0)
                     sep = 2.0*np.arcsin(np.sqrt(np.sum(lm_sin**2))/2.0)
+                    #print('lm_sin',lm_sin,lmn_rot,np.sqrt(lm_sin[0]**2 + lm_sin[1]**2),sep)
                     
                 if do_pointing:
                     if not(np.array_equal(prev_ra_dec_in, ra_dec_in_1) and np.array_equal(prev_ra_dec_out, ra_dec_out)):
@@ -174,6 +175,8 @@ def calc_vis_jit(vis_data,uvw,vis_data_shape,point_source_flux,point_source_ra_d
                         flux_scaled, outside_beam = calc_pb_scale(flux,sep_1,sep_2,bm1_indx,bm2_indx,bm1_type,bm2_type,lm_sin_1,lm_sin_2,beam_models_type0,beam_models_type1,pa,freq_chan[i_chan],mueller_selection,do_pointing)
                     else:
                         flux_scaled, outside_beam = calc_pb_scale(flux,sep,sep,bm1_indx,bm2_indx,bm1_type,bm2_type,lm_sin,lm_sin,beam_models_type0,beam_models_type1,pa,freq_chan[i_chan],mueller_selection,do_pointing)
+                        
+                    
                     #print('flux_scaled', flux_scaled, outside_beam, beam_models_type1[bm1_indx], beam_models_type1[bm2_indx])
                     #print("s2",time.time()-s2)
                     if not outside_beam:
@@ -219,13 +222,17 @@ def beam_models_to_tuple(beam_models,beam_model_map):
             new_beam_model_map[beam_model_map==i] = i_t1
             i_t1 = i_t1 + 1
             
+    #Dummy for sample_j
     if not bool(beam_models_list_type0):
-        d_arr = np.array([0])
+        d_arr_float = np.array([0.])
+        d_arr_int = np.array([0])
         d_J = np.zeros((1,1,1,1,1),np.complex128)
-        beam_models_list_type0.append((0,d_J,d_arr,d_arr,d_arr,d_arr,d_arr,0.0))
+        beam_models_list_type0.append((0,d_J,d_arr_float,d_arr_float,
+                                        d_arr_int,d_arr_float,d_arr_float,0.0))
     
+    #Dummy for sample_j_analytic
     if not bool(beam_models_list_type1):
-        beam_models_list_type1.append((1,"none",0,0,0.0))
+        beam_models_list_type1.append((1,"none",0.,0.,0.0))
     
     return tuple(beam_models_list_type0), tuple(beam_models_list_type1), tuple(beam_types), tuple(new_beam_model_map)
 
@@ -236,8 +243,8 @@ def exstract_arrays_from_bm_xds(bm):
     pa = bm.pa.values
     chan = bm.chan.values
     pol = bm.pol.values
-    delta_l = bm.l[1].values - bm.l[0].values
-    delta_m = bm.m[1].values - bm.m[0].values
+    delta_l = (bm.l[1].values - bm.l[0].values).astype(float)
+    delta_m = (bm.m[1].values - bm.m[0].values).astype(float)
     print(bm)
     max_rad_1GHz = bm.attrs['max_rad_1GHz']
     return (0,bm_J,pa,chan,pol,delta_l,delta_m,max_rad_1GHz)
@@ -266,6 +273,7 @@ def calc_pb_scale(flux, sep1, sep2, bm1_indx,bm2_indx,bm1_type,bm2_type,lmn1,lmn
             if sep1 < max_rad:
                 #bm1 = beam_models_type0[bm1_indx]
                 J_sampled = sample_J(bm1[1],bm1[2],bm1[3],bm1[4],bm1[5],bm1[6],pa,freq,lmn1)[:,0]
+                
                 #J_sampled = np.zeros((4,),dtype=numba.complex128)
                 M = make_mueler_mat(J_sampled, J_sampled, mueller_selection)
                 #Add check if J sampled is < 0 and then skip this
@@ -278,6 +286,7 @@ def calc_pb_scale(flux, sep1, sep2, bm1_indx,bm2_indx,bm1_type,bm2_type,lmn1,lmn
             max_rad = bm1[4]*freq/10**9 # scale max_rad_1GHz to freq
             if sep1 < max_rad:
                 J_sampled = sample_J_analytic(bm1[1],bm1[2],bm1[3],lmn1,freq,1)
+                #print('J_sampled',J_sampled,bm1[1],bm1[2],bm1[3],lmn1,freq,1)
                 flux_scaled = flux*J_sampled**2
             else:
                 outside_beam = True
